@@ -1,17 +1,7 @@
-from os.path import dirname
-
-import pytest
-
 from test.helpers import get_example_dir, example_dir
 from jedi import Project
 
 
-@pytest.fixture(autouse=True)
-def skip_not_supported_versions(environment):
-    if environment.version_info < (3, 5):
-        pytest.skip()
-
-
 def test_implicit_namespace_package(Script):
     sys_path = [get_example_dir('implicit_namespace_package', 'ns1'),
                 get_example_dir('implicit_namespace_package', 'ns2')]
@@ -65,7 +55,7 @@ def test_implicit_nested_namespace_package(Script):
     assert len(result) == 1
 
     implicit_pkg, = Script(code, project=project).infer(column=10)
-    assert implicit_pkg.type == 'module'
+    assert implicit_pkg.type == 'namespace'
     assert implicit_pkg.module_path is None
 
 
